@@ -2,9 +2,9 @@
 
 # Key is the codec format returned by MediaInfo
 CODEC_DATA = {
-    "HEVC": {"ffmpeg_name": "libx265", "pretty_name": "x265"},
-    "AVC": {"ffmpeg_name": "h264", "pretty_name": "x264"},
-    "AAC": {"ffmpeg_name": "aac", "pretty_name": "aac"},
+    "HEVC": {"ffmpeg_names": {"software": "libx265", "nvidia": "hevc_nvenc", "intel": "hevc_qsv"}, "pretty_name": "x265"},
+    "AVC": {"ffmpeg_names": {"software": "h264", "nvidia": "h264_nvenc", "intel": "h264_qsv"}, "pretty_name": "x264"},
+    "AAC": {"ffmpeg_names": {"software": "aac"}, "pretty_name": "aac"},
 }
 
 
@@ -12,7 +12,7 @@ class Codec:
 
     def __init__(self, format_name, ffmpeg_name=None, pretty_name=None):
         self.format_name = format_name
-        self.ffmpeg_name = ffmpeg_name
+        self._ffmpeg_name = ffmpeg_name
         self.pretty_name = pretty_name
         self._autodetect()
 
@@ -31,9 +31,16 @@ class Codec:
 
     def _autodetect(self):
         try:
-            data = CODEC_DATA[next(
+            self._data = CODEC_DATA[next(
                 x for x in CODEC_DATA if x == self.format_name)]
-            self.ffmpeg_name = self.ffmpeg_name if self.ffmpeg_name else data["ffmpeg_name"]
-            self.pretty_name = self.pretty_name if self.pretty_name else data["pretty_name"]
+            self.pretty_name = self.pretty_name if self.pretty_name else self._data["pretty_name"]
         except StopIteration:
             pass  # No match found
+
+    def get_ffmpeg_name(self, encoder="software"):
+        if self._ffmpeg_name:
+            return self._ffmpeg_name
+        try:
+            return self._data["ffmpeg_names"][encoder]
+        except:
+            return None
\ No newline at end of file
